@@ -4,6 +4,7 @@
  */
 
 #include <net-snmp/net-snmp-config.h>
+#include <net-snmp/net-snmp-features.h>
 #include <net-snmp/net-snmp-includes.h>
 #include <net-snmp/agent/net-snmp-agent-includes.h>
 #include <net-snmp/agent/agent_callbacks.h>
@@ -14,6 +15,7 @@
 
 #include <ctype.h>
 
+netsnmp_feature_require(iquery);
 
 /** Initializes the mteTriggerConf module */
 void
@@ -505,13 +507,12 @@ parse_mteMonitor(const char *token, const char *line)
                     memcpy(oid_name_buf, buf, SPRINT_MAX_LEN);
                     memset(         buf,   0, SPRINT_MAX_LEN);
                     cp  = copy_nword_const(cp, buf, SPRINT_MAX_LEN);
-                        value = strtol(buf, NULL, 0);
+                    value = strtol(buf, NULL, 0);
     
                     /*
                      * ... then save the rest of the line for later.
                      */
-                    memset( buf, 0,  strlen(buf));
-                    memcpy( buf, cp, strlen(cp));
+                    strlcpy(buf, cp, sizeof(buf));
                     cp = NULL;  /* To terminate the processing loop */
                     DEBUGMSGTL(("disman:event:conf", "%s: Thresh (%s, %ld, %s)\n",
                                               tname, oid_name_buf, value, buf));
