@@ -38,7 +38,7 @@ int
 netsnmp_arch_swrun_container_load( netsnmp_container *container, u_int flags)
 {
     /* Nothing to do */
-    DEBUGMSGTL(("swrun:load:arch"," loaded %d entries\n",
+    DEBUGMSGTL(("swrun:load:arch"," loaded %" NETSNMP_PRIz "u entries\n",
                 CONTAINER_SIZE(container)));
 
     return 0;
