@@ -26,19 +26,19 @@
 #include "hr_filesys.h"
 #include <net-snmp/utilities.h>
 
-#if HAVE_MNTENT_H
+#ifdef HAVE_MNTENT_H
 #include <mntent.h>
 #endif
-#if HAVE_SYS_MNTENT_H
+#ifdef HAVE_SYS_MNTENT_H
 #include <sys/mntent.h>
 #endif
-#if HAVE_SYS_MNTTAB_H
+#ifdef HAVE_SYS_MNTTAB_H
 #include <sys/mnttab.h>
 #endif
-#if HAVE_SYS_STATVFS_H
+#ifdef HAVE_SYS_STATVFS_H
 #include <sys/statvfs.h>
 #endif
-#if HAVE_SYS_VFS_H
+#ifdef HAVE_SYS_VFS_H
 #include <sys/vfs.h>
 #endif
 #ifdef HAVE_SYS_PARAM_H
@@ -73,14 +73,11 @@ netsnmp_feature_require(ctime_to_timet);
 	 *   and internal forward declarations
 	 *
 	 *********************/
-netsnmp_fsys_info *HRFS_entry;
 
 #define	FULL_DUMP	0
 #define	PART_DUMP	1
 
-static u_char  *when_dumped(char *filesys, int level, size_t * length);
-int             header_hrhfilesys(struct variable *, oid *, size_t *, int,
-                                 size_t *, WriteMethod **);
+static u_char *when_dumped(const char *filesys, int level, size_t *length);
 
         /*********************
 	 *
@@ -139,11 +136,10 @@ init_hrh_filesys(void)
  * 
  */
 
-int
-header_hrhfilesys(struct variable *vp,
-                 oid * name,
-                 size_t * length,
-                 int exact, size_t * var_len, WriteMethod ** write_method)
+static int
+header_hrhfilesys(struct variable *vp, oid *name, size_t *length,
+                  int exact, size_t *var_len, WriteMethod **write_method,
+                  const netsnmp_fsys_info **entry)
 {
 #define HRFSYS_ENTRY_NAME_LENGTH	11
     oid             newname[MAX_OID_LEN];
@@ -159,9 +155,10 @@ header_hrhfilesys(struct variable *vp,
      * Find "next" file system entry 
      */
 
+    *entry = NULL;
     Init_HR_FileSys();
     for (;;) {
-        fsys_idx = Get_Next_HR_FileSys();
+        fsys_idx = Get_Next_HR_FileSys(entry);
         if (fsys_idx == -1)
             break;
         newname[HRFSYS_ENTRY_NAME_LENGTH] = fsys_idx;
@@ -220,9 +217,10 @@ var_hrhfilesys(struct variable *vp,
     int             fsys_idx;
     static char    *string;
     static char     empty_str[1];
+    const netsnmp_fsys_info *entry = NULL;
 
-    fsys_idx =
-        header_hrhfilesys(vp, name, length, exact, var_len, write_method);
+    fsys_idx = header_hrhfilesys(vp, name, length, exact, var_len, write_method,
+                                 &entry);
     if (fsys_idx == MATCH_FAILED)
         return NULL;
 
@@ -234,13 +232,13 @@ var_hrhfilesys(struct variable *vp,
         free(string);
         string = NULL;
         *var_len = 0;
-        if (asprintf(&string, "%s", HRFS_entry->path) >= 0)
+        if (asprintf(&string, "%s", entry->path) >= 0)
             *var_len = strlen(string);
         return (u_char *)(string ? string : empty_str);
     case HRFSYS_RMOUNT:
         free(string);
-        if (HRFS_entry->flags & NETSNMP_FS_FLAG_REMOTE) {
-            if (asprintf(&string, "%s", HRFS_entry->device) < 0)
+        if (entry->flags & NETSNMP_FS_FLAG_REMOTE) {
+            if (asprintf(&string, "%s", entry->device) < 0)
                 string = NULL;
         } else {
             string = strdup("");
@@ -249,25 +247,25 @@ var_hrhfilesys(struct variable *vp,
         return (u_char *)(string ? string : empty_str);
 
     case HRFSYS_TYPE:
-        fsys_type_id[fsys_type_len - 1] = 
-            (HRFS_entry->type > _NETSNMP_FS_TYPE_LOCAL ?
-                                 NETSNMP_FS_TYPE_OTHER : HRFS_entry->type);
+        fsys_type_id[fsys_type_len - 1] =
+            (entry->type > _NETSNMP_FS_TYPE_LOCAL ?
+             NETSNMP_FS_TYPE_OTHER : entry->type);
         *var_len = sizeof(fsys_type_id);
         return (u_char *) fsys_type_id;
 
     case HRFSYS_ACCESS:
-	long_return = HRFS_entry->flags & NETSNMP_FS_FLAG_RONLY ? 2 : 1;
+	long_return = entry->flags & NETSNMP_FS_FLAG_RONLY ? 2 : 1;
         return (u_char *) & long_return;
     case HRFSYS_BOOT:
-	long_return = HRFS_entry->flags & NETSNMP_FS_FLAG_BOOTABLE ? 1 : 2;
+	long_return = entry->flags & NETSNMP_FS_FLAG_BOOTABLE ? 1 : 2;
         return (u_char *) & long_return;
     case HRFSYS_STOREIDX:
         long_return = fsys_idx + NETSNMP_MEM_TYPE_MAX;
         return (u_char *) & long_return;
     case HRFSYS_FULLDUMP:
-        return when_dumped(HRFS_entry->path, FULL_DUMP, var_len);
+        return when_dumped(entry->path, FULL_DUMP, var_len);
     case HRFSYS_PARTDUMP:
-        return when_dumped(HRFS_entry->path, PART_DUMP, var_len);
+        return when_dumped(entry->path, PART_DUMP, var_len);
     default:
         DEBUGMSGTL(("snmpd", "unknown sub-id %d in var_hrhfilesys\n",
                     vp->magic));
@@ -281,43 +279,35 @@ var_hrhfilesys(struct variable *vp,
 	 *  Internal implementation functions
 	 *
 	 *********************/
-static int      HRFS_index;
 
 void
 Init_HR_FileSys(void)
 {
     netsnmp_cache *c = netsnmp_fsys_get_cache();
-    netsnmp_cache_check_and_reload( c );
-
-    HRFS_entry = NULL;
-    HRFS_index = 0;
+    netsnmp_cache_check_and_reload(c);
 }
 
 int
-Get_Next_HR_FileSys(void)
+Get_Next_HR_FileSys(const netsnmp_fsys_info **entry)
 {
-    if ( HRFS_entry ) {
-        HRFS_entry = netsnmp_fsys_get_next( HRFS_entry );
-    } else {     
-        HRFS_entry = netsnmp_fsys_get_first();
-    }
+    *entry = *entry ? netsnmp_fsys_get_next(*entry) : netsnmp_fsys_get_first();
     /* Skip "inactive" entries */
-    while ( HRFS_entry && !(HRFS_entry->flags & NETSNMP_FS_FLAG_ACTIVE))
-        HRFS_entry = netsnmp_fsys_get_next( HRFS_entry );
+    while (*entry && !((*entry)->flags & NETSNMP_FS_FLAG_ACTIVE))
+        *entry = netsnmp_fsys_get_next(*entry);
 
-    HRFS_index = (HRFS_entry ? HRFS_entry->idx.oids[0] : -1 );
-    return HRFS_index;
+    return *entry ? (*entry)->idx.oids[0] : -1;
 }
 
 
 
 static u_char  *
-when_dumped(char *filesys, int level, size_t * length)
+when_dumped(const char *filesys, int level, size_t *length)
 {
     time_t          dumpdate = 0, tmp;
     FILE           *dump_fp;
     char            line[1024];
-    char           *cp1, *cp2, *cp3;
+    const char     *cp1;
+    char           *cp2, *cp3;
 
     /*
      * Look for the relevent entries in /etc/dumpdates
@@ -426,13 +416,13 @@ Get_FSSize(char *dev)
 }
 
 int
-Check_HR_FileSys_NFS (void)
+Check_HR_FileSys_NFS(const netsnmp_fsys_info *entry)
 {
-    return (HRFS_entry->flags & NETSNMP_FS_FLAG_REMOTE) ? 1 : 0;
+    return entry->flags & NETSNMP_FS_FLAG_REMOTE ? 1 : 0;
 }
 
 int
-Check_HR_FileSys_AutoFs (void)
+Check_HR_FileSys_AutoFs(const netsnmp_fsys_info *entry)
 {
-    return HRFS_entry->type == NETSNMP_FS_TYPE_AUTOFS;
+    return entry->type == NETSNMP_FS_TYPE_AUTOFS;
 }
