@@ -5,12 +5,14 @@
 #ifndef _MIBGROUP_HRFSYS_H
 #define _MIBGROUP_HRFSYS_H
 
+struct netsnmp_fsys_info_s;
+
 extern void     init_hrh_filesys(void);
 extern void     Init_HR_FileSys(void);
 extern FindVarMethod var_hrhfilesys;
-extern int      Get_Next_HR_FileSys(void);
-extern int      Check_HR_FileSys_NFS(void);
-extern int	Check_HR_FileSys_AutoFs(void);
+extern int      Get_Next_HR_FileSys(const struct netsnmp_fsys_info_s **entry);
+extern int      Check_HR_FileSys_NFS(const struct netsnmp_fsys_info_s *entry);
+extern int	Check_HR_FileSys_AutoFs(const struct netsnmp_fsys_info_s *entry);
 
 extern int      Get_FSIndex(char *);
 extern long     Get_FSSize(char *);     /* Temporary */
