@@ -12,6 +12,7 @@
 #include "hrh_filesys.h"
 #include "hrh_storage.h"
 #include "hr_disk.h"
+#include "hr_filesys.h"
 #include <net-snmp/utilities.h>
 
 
@@ -26,7 +27,6 @@
 # ifdef WIN32
 #  include <windows.h>
 #  include <errno.h>
-#  include <sys/timeb.h>
 # else
 #  include <sys/time.h>
 # endif
@@ -64,8 +64,6 @@
 	 *********************/
 
 
-extern netsnmp_fsys_info *HRFS_entry;
-
 static void parse_storage_config(const char *, char *);
 
         /*********************
@@ -73,12 +71,9 @@ static void parse_storage_config(const char *, char *);
 	 *  Initialisation & common implementation functions
 	 *
 	 *********************/
-int             Get_Next_HR_Store(void);
+int             Get_Next_HR_Store(const struct netsnmp_fsys_info_s **entry);
 void            Init_HR_Store(void);
-int             header_hrstore(struct variable *, oid *, size_t *, int,
-                               size_t *, WriteMethod **);
-void*           header_hrstoreEntry(struct variable *, oid *, size_t *,
-                                    int, size_t *, WriteMethod **);
+
 Netsnmp_Node_Handler handle_memsize;
 
 
@@ -171,13 +166,10 @@ parse_storage_config(const char *token, char *cptr)
  * write_method
  * 
  */
-
-void *
-header_hrstoreEntry(struct variable *vp,
-                    oid * name,
-                    size_t * length,
-                    int exact,
-                    size_t * var_len, WriteMethod ** write_method)
+static void *
+header_hrstoreEntry(struct variable *vp, oid *name, size_t *length, int exact,
+                    size_t *var_len, WriteMethod **write_method,
+                    const netsnmp_fsys_info **entry)
 {
 #define HRSTORE_ENTRY_NAME_LENGTH	11
     oid             newname[MAX_OID_LEN];
@@ -244,9 +236,10 @@ header_hrstoreEntry(struct variable *vp,
      *   then consider the disk-based storage.
      */
     else {
+        *entry = NULL;
         Init_HR_Store();
         for (;;) {
-            storage_idx = Get_Next_HR_Store();
+            storage_idx = Get_Next_HR_Store(entry);
             DEBUGMSG(("host/hr_storage", "(index %d ....", storage_idx));
             if (storage_idx == -1)
                 break;
@@ -357,24 +350,27 @@ var_hrstore(struct variable *vp,
     int             store_idx = 0;
     static char     string[1024];
     void                *ptr;
+    const netsnmp_fsys_info *entry = NULL;
     netsnmp_memory_info *mem = NULL;
 
 really_try_next:
-	ptr = header_hrstoreEntry(vp, name, length, exact, var_len,
-					write_method);
-	if (ptr == NULL)
-	    return NULL;
+    ptr = header_hrstoreEntry(vp, name, length, exact, var_len, write_method,
+                              &entry);
+    if (ptr == NULL)
+        return NULL;
 
-        store_idx = name[ HRSTORE_ENTRY_NAME_LENGTH ];
-        if (HRFS_entry &&
-	    store_idx > NETSNMP_MEM_TYPE_MAX &&
-            netsnmp_ds_get_boolean(NETSNMP_DS_APPLICATION_ID,
-                                   NETSNMP_DS_AGENT_SKIPNFSINHOSTRESOURCES) &&
-            Check_HR_FileSys_NFS())
-            return NULL;
-        if (store_idx <= NETSNMP_MEM_TYPE_MAX ) {
-	    mem = (netsnmp_memory_info*)ptr;
-        }
+    store_idx = name[ HRSTORE_ENTRY_NAME_LENGTH ];
+    if (entry &&
+        store_idx > NETSNMP_MEM_TYPE_MAX &&
+        netsnmp_ds_get_boolean(NETSNMP_DS_APPLICATION_ID,
+                               NETSNMP_DS_AGENT_SKIPNFSINHOSTRESOURCES) &&
+        Check_HR_FileSys_NFS(entry))
+        return NULL;
+    if (entry && Check_HR_FileSys_AutoFs(entry))
+        return NULL;
+    if (store_idx <= NETSNMP_MEM_TYPE_MAX ) {
+        mem = (netsnmp_memory_info*)ptr;
+    }
 
 
 
@@ -384,9 +380,9 @@ really_try_next:
         return (u_char *) & long_return;
     case HRSTORE_TYPE:
         if (store_idx > NETSNMP_MEM_TYPE_MAX)
-            if (HRFS_entry->flags & NETSNMP_FS_FLAG_REMOTE )
+            if (entry->flags & NETSNMP_FS_FLAG_REMOTE && storageUseNFS)
                 storage_type_id[storage_type_len - 1] = 10;     /* Network Disk */
-            else if (HRFS_entry->flags & NETSNMP_FS_FLAG_REMOVE )
+            else if (entry->flags & NETSNMP_FS_FLAG_REMOVE )
                 storage_type_id[storage_type_len - 1] = 5;      /* Removable Disk */
             else
                 storage_type_id[storage_type_len - 1] = 4;      /* Assume fixed */
@@ -408,7 +404,7 @@ really_try_next:
         return (u_char *) storage_type_id;
     case HRSTORE_DESCR:
         if (store_idx > NETSNMP_MEM_TYPE_MAX) {
-            strlcpy(string, HRFS_entry->path, sizeof(string));
+            strlcpy(string, entry->path, sizeof(string));
             *var_len = strlen(string);
             return (u_char *) string;
         } else {
@@ -420,40 +416,40 @@ really_try_next:
     case HRSTORE_UNITS:
         if (store_idx > NETSNMP_MEM_TYPE_MAX) {
             if (netsnmp_ds_get_boolean(NETSNMP_DS_APPLICATION_ID,
-                    NETSNMP_DS_AGENT_REALSTORAGEUNITS))
-                long_return = HRFS_entry->units & 0xffffffff;
+                                       NETSNMP_DS_AGENT_REALSTORAGEUNITS))
+                long_return = entry->units & 0x7fffffff;
             else
-                long_return = HRFS_entry->units_32;
+                long_return = entry->units_32;
         } else {
             if ( !mem || mem->units == -1 )
                 goto try_next;
-            long_return = mem->units;
+            long_return = mem->units & 0x7fffffff;
         }
         return (u_char *) & long_return;
     case HRSTORE_SIZE:
         if (store_idx > NETSNMP_MEM_TYPE_MAX) {
             if (netsnmp_ds_get_boolean(NETSNMP_DS_APPLICATION_ID,
-                    NETSNMP_DS_AGENT_REALSTORAGEUNITS))
-                long_return = HRFS_entry->size & 0xffffffff;
+                                       NETSNMP_DS_AGENT_REALSTORAGEUNITS))
+                long_return = entry->size & 0x7fffffff;
             else
-                long_return = HRFS_entry->size_32;
+                long_return = entry->size_32;
         } else {
             if ( !mem || mem->size == -1 )
                 goto try_next;
-            long_return = mem->size;
+            long_return = mem->size & 0x7fffffff;
         }
         return (u_char *) & long_return;
     case HRSTORE_USED:
         if (store_idx > NETSNMP_MEM_TYPE_MAX) {
             if (netsnmp_ds_get_boolean(NETSNMP_DS_APPLICATION_ID,
-                    NETSNMP_DS_AGENT_REALSTORAGEUNITS))
-                long_return = HRFS_entry->used & 0xffffffff;
+                                       NETSNMP_DS_AGENT_REALSTORAGEUNITS))
+                long_return = entry->used & 0x7fffffff;
             else
-                long_return = HRFS_entry->used_32;
+                long_return = entry->used_32;
         } else {
             if ( !mem || mem->size == -1 || mem->free == -1 )
                 goto try_next;
-            long_return = mem->size - mem->free;
+            long_return = (mem->size - mem->free) & 0x7fffffff;
         }
         return (u_char *) & long_return;
     case HRSTORE_FAILS:
@@ -461,7 +457,7 @@ really_try_next:
 #if NETSNMP_NO_DUMMY_VALUES
 	    goto try_next;
 #else
-            long_return = 0;
+        long_return = 0;
 #endif
         else {
             if ( !mem || mem->other == -1 )
@@ -475,7 +471,7 @@ really_try_next:
     }
     return NULL;
 
-  try_next:
+try_next:
     if (!exact)
         goto really_try_next;
 
@@ -489,32 +485,28 @@ really_try_next:
 	 *
 	 *********************/
 
-static int      HRS_index;
-
 void
 Init_HR_Store(void)
 {
-    HRS_index = 0;
     Init_HR_FileSys();
 }
 
 int
-Get_Next_HR_Store(void)
+Get_Next_HR_Store(const struct netsnmp_fsys_info_s **entry)
 {
     /*
      * File-based storage 
      */
-	for (;;) {
-    	HRS_index = Get_Next_HR_FileSys();
-		if (HRS_index >= 0) {
-			if (!(netsnmp_ds_get_boolean(NETSNMP_DS_APPLICATION_ID, 
-							NETSNMP_DS_AGENT_SKIPNFSINHOSTRESOURCES) && 
-						Check_HR_FileSys_NFS())) {
-				return HRS_index + NETSNMP_MEM_TYPE_MAX;	
-			}
-		} else {
-			return -1;
-		}	
-	}
+    for (;;) {
+	Get_Next_HR_FileSys(entry);
+        if (!*entry)
+            return -1;
+        if (!(netsnmp_ds_get_boolean(NETSNMP_DS_APPLICATION_ID, 
+                                  NETSNMP_DS_AGENT_SKIPNFSINHOSTRESOURCES) && 
+              Check_HR_FileSys_NFS(*entry)) &&
+            !Check_HR_FileSys_AutoFs(*entry)) {
+            return (*entry)->idx.oids[0] + NETSNMP_MEM_TYPE_MAX;	
+        }
+    }
 }
 
