@@ -22,6 +22,8 @@ config_require(ip-mib/data_access/systemstats_common)
 config_require(ip-mib/data_access/systemstats_linux)
 #elif defined( solaris2 )
 config_require(ip-mib/data_access/systemstats_solaris2)
+#elif defined( freebsd7 ) || defined( netbsd5 ) || defined( openbsd4 ) || defined( dragonfly ) || defined( darwin )
+config_require(ip-mib/data_access/systemstats_sysctl)
 #else
 config_error(the systemstats data access library is not available in this environment.)
 #endif
