@@ -164,8 +164,6 @@ _systemstats_v4(netsnmp_container* container, u_int load_flags)
         entry = netsnmp_access_systemstats_entry_create(1, 0,
                     "ipSystemStatsTable.ipv4");
         if(NULL == entry) {
-            netsnmp_access_systemstats_container_free(container,
-                                                      NETSNMP_ACCESS_SYSTEMSTATS_FREE_NOFLAGS);
             return -3;
         }
 
