@@ -6,7 +6,9 @@
 #ifndef _MIBGROUP_AT_H
 #define _MIBGROUP_AT_H
 
-config_arch_require(solaris2, kernel_sunos5)
+#ifdef HAVE_NET_ROUTE_H
+#include <net/route.h>
+#endif
 
      extern void     init_at(void);
      extern FindVarMethod var_atEntry;
@@ -21,18 +23,8 @@ config_arch_require(solaris2, kernel_sunos5)
 #define IPMEDIANETADDRESS       2
 #define IPMEDIATYPE             3
 
-/*
- * in case its missing: 
- */
-#ifndef ATF_PERM
-# define ATF_PERM	0x04
-#endif                          /*  ATF_PERM */
-#ifndef ATF_COM
-# define ATF_COM	0x02
-#endif                          /*  ATF_COM */
-
 /* InfiniBand uses HW addr > 6 */
-#define MAX_MAC_ADDR_LEN 32 
+#define MAX_MAC_ADDR_LEN 32
 
 #if defined(linux) || defined(irix6)
 /*
@@ -46,4 +38,26 @@ config_arch_require(solaris2, kernel_sunos5)
          int             if_index;
      };
 #endif
+
+#if !defined(WIN32) && !defined(cygwin) && !defined(solaris2)
+void     ARP_Scan_Init(void);
+int      ARP_Scan_Next(in_addr_t *, char *, int *, u_long *, u_short *);
+#endif
+
+#if defined(WIN32) || defined(cygwin)
+config_require(mibII/data_access/at_iphlpapi)
+#elif defined(solaris2)
+config_require(kernel_sunos5)
+config_require(mibII/data_access/at_solaris)
+#elif defined(linux)
+config_require(mibII/data_access/at_linux)
+config_require(mibII/data_access/at_unix)
+#elif defined(HAVE_SYS_SYSCTL_H) && (defined(RTF_LLINFO) || defined(RTF_LLDATA))
+config_require(mibII/data_access/at_sysctl)
+config_require(mibII/data_access/at_unix)
+#elif defined(HAVE_NLIST_H)
+config_require(mibII/data_access/at_nlist)
+config_require(mibII/data_access/at_unix)
+#endif
+
 #endif                          /* _MIBGROUP_AT_H */
