@@ -17,6 +17,8 @@ config_require(sctp-mib/sctpTables_linux)
 config_require(util_funcs/get_pid_from_inode)
 #elif defined( freebsd7 ) || defined( freebsd8 )
 config_require(sctp-mib/sctpTables_freebsd)
+#elif defined( solaris2 )
+config_require(sctp-mib/sctpTables_solaris2)
 #else
 config_error(SCTP-MIB is not available in tihs environment)
 #endif
