@@ -7,10 +7,15 @@
 
 void            init_extensible(void);
 
+config_require(ucd-snmp/pass)
 config_require(util_funcs/header_simple_table)
 config_require(util_funcs)
 config_require(utilities/execute)
 
+     extern struct extensible *extens;
+     extern struct extensible *relocs;
+     extern int numextens, numrelocs;
+
      extern FindVarMethod var_extensible_shell;
      extern WriteMethod fixExecError;
      extern FindVarMethod var_extensible_relocatable;
