@@ -10,7 +10,11 @@ config_require(util_funcs)
 
      extern FindVarMethod var_extensible_proc;
      extern WriteMethod fixProcError;
+     int sh_count_myprocs(struct myproc *);
      int             sh_count_procs(char *);
+#ifdef HAVE_PCRE_H
+     int sh_count_procs_by_regex(char *, netsnmp_regex_ptr);
+#endif
 
 /*
  * config file parsing routines 
@@ -19,10 +23,4 @@ config_require(util_funcs)
      void            proc_parse_config(const char *, char *);
      void            procfix_parse_config(const char *, char *);
 
-#include "mibdefs.h"
-
-#define PROCMIN 3
-#define PROCMAX 4
-#define PROCCOUNT 5
-
 #endif                          /* _MIBGROUP_PROC_H */
