@@ -3,7 +3,7 @@ config_require(ucd-snmp/proc)
 config_require(ucd-snmp/versioninfo)
 config_require(ucd-snmp/pass)
 config_require(ucd-snmp/pass_persist)
-config_version_require((ucd-snmp/disk, 5.7, ucd-snmp/disk_hw))
+config_require(ucd-snmp/disk_hw)
 config_require(ucd-snmp/loadave)
 config_require(agent/extend)
 config_require(ucd-snmp/errormib)
