@@ -37,16 +37,16 @@ SOFTWARE.
 #include <strings.h>
 #endif
 #include <sys/types.h>
-#if HAVE_SYS_WAIT_H
+#ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
 #endif
-#if HAVE_SYS_SOCKET_H
+#ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
-#if HAVE_SYS_SOCKIO_H
+#ifdef HAVE_SYS_SOCKIO_H
 #include <sys/sockio.h>
 #endif
-#if HAVE_NETINET_IN_H
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
 #include <stdio.h>
@@ -58,37 +58,37 @@ SOFTWARE.
 #else
 # include <time.h>
 #endif
-#if HAVE_SYS_SELECT_H
+#ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
 #if HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
-#if HAVE_SYSLOG_H
+#ifdef HAVE_SYSLOG_H
 #include <syslog.h>
 #endif
-#if HAVE_SYS_IOCTL_H
+#ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
 #endif
-#if HAVE_NET_IF_H
+#ifdef HAVE_NET_IF_H
 #include <net/if.h>
 #endif
-#if HAVE_NETDB_H
+#ifdef HAVE_NETDB_H
 #include <netdb.h>
 #endif
-#if HAVE_ARPA_INET_H
+#ifdef HAVE_ARPA_INET_H
 #include <arpa/inet.h>
 #endif
 #if HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
-#if HAVE_PROCESS_H              /* Win32-getpid */
+#ifdef HAVE_PROCESS_H
 #include <process.h>
 #endif
-#if HAVE_PWD_H
+#ifdef HAVE_PWD_H
 #include <pwd.h>
 #endif
-#if HAVE_GRP_H
+#ifdef HAVE_GRP_H
 #include <grp.h>
 #endif
 #include <signal.h>
@@ -98,6 +98,7 @@ SOFTWARE.
 #include <net-snmp/agent/net-snmp-agent-includes.h>
 #include <net-snmp/library/fd_event_manager.h>
 #include <net-snmp/agent/netsnmp_close_fds.h>
+#include "../snmplib/snmp_syslog.h"
 #include "../agent_global_vars.h"
 #include "../agent/mibgroup/snmpv3/snmpEngine.h"
 #include "../agent/mibgroup/snmpv3/usmUser.h"
@@ -126,7 +127,7 @@ SOFTWARE.
 
 #endif
 
-#if NETSNMP_USE_LIBWRAP
+#ifdef NETSNMP_USE_LIBWRAP
 #include <tcpd.h>
 #endif
 
@@ -151,43 +152,6 @@ char           *default_port = ddefault_port;
 char           *trap1_fmt_str_remember = NULL;
 int             dofork = 1;
 
-/*
- * These definitions handle 4.2 systems without additional syslog facilities.
- */
-#ifndef LOG_CONS
-#define LOG_CONS	0       /* Don't bother if not defined... */
-#endif
-#ifndef LOG_PID
-#define LOG_PID		0       /* Don't bother if not defined... */
-#endif
-#ifndef LOG_LOCAL0
-#define LOG_LOCAL0	0
-#endif
-#ifndef LOG_LOCAL1
-#define LOG_LOCAL1	0
-#endif
-#ifndef LOG_LOCAL2
-#define LOG_LOCAL2	0
-#endif
-#ifndef LOG_LOCAL3
-#define LOG_LOCAL3	0
-#endif
-#ifndef LOG_LOCAL4
-#define LOG_LOCAL4	0
-#endif
-#ifndef LOG_LOCAL5
-#define LOG_LOCAL5	0
-#endif
-#ifndef LOG_LOCAL6
-#define LOG_LOCAL6	0
-#endif
-#ifndef LOG_LOCAL7
-#define LOG_LOCAL7	0
-#endif
-#ifndef LOG_DAEMON
-#define LOG_DAEMON	0
-#endif
-
 /*
  * Include an extra Facility variable to allow command line adjustment of
  * syslog destination 
@@ -317,7 +281,7 @@ static int
 pre_parse(netsnmp_session * session, netsnmp_transport *transport,
           void *transport_data, int transport_data_length)
 {
-#if NETSNMP_USE_LIBWRAP
+#ifdef NETSNMP_USE_LIBWRAP
     char *addr_string = NULL;
 
     if (transport != NULL && transport->f_fmtaddr != NULL) {
@@ -448,65 +412,6 @@ parse_config_pidFile(const char *token, char *cptr)
   pid_file = strdup (cptr);
 }
 
-#ifdef HAVE_UNISTD_H
-void
-parse_config_agentuser(const char *token, char *cptr)
-{
-    if (cptr[0] == '#') {
-        char           *ecp;
-        int             uid;
-
-        uid = strtoul(cptr + 1, &ecp, 10);
-        if (*ecp != 0) {
-            config_perror("Bad number");
-	} else {
-	    netsnmp_ds_set_int(NETSNMP_DS_APPLICATION_ID, 
-			       NETSNMP_DS_AGENT_USERID, uid);
-	}
-#if defined(HAVE_GETPWNAM) && defined(HAVE_PWD_H)
-    } else {
-        struct passwd *info;
-
-        info = getpwnam(cptr);
-        if (info)
-            netsnmp_ds_set_int(NETSNMP_DS_APPLICATION_ID, 
-                               NETSNMP_DS_AGENT_USERID, info->pw_uid);
-        else
-            config_perror("User not found in passwd database");
-        endpwent();
-#endif
-    }
-}
-
-void
-parse_config_agentgroup(const char *token, char *cptr)
-{
-    if (cptr[0] == '#') {
-        char           *ecp;
-        int             gid = strtoul(cptr + 1, &ecp, 10);
-
-        if (*ecp != 0) {
-            config_perror("Bad number");
-	} else {
-            netsnmp_ds_set_int(NETSNMP_DS_APPLICATION_ID, 
-			       NETSNMP_DS_AGENT_GROUPID, gid);
-	}
-#if defined(HAVE_GETGRNAM) && defined(HAVE_GRP_H)
-    } else {
-        struct group   *info;
-
-        info = getgrnam(cptr);
-        if (info)
-            netsnmp_ds_set_int(NETSNMP_DS_APPLICATION_ID, 
-                               NETSNMP_DS_AGENT_GROUPID, info->gr_gid);
-        else
-            config_perror("Group not found in group database");
-        endgrent();
-#endif
-    }
-}
-#endif
-
 void
 parse_config_doNotFork(const char *token, char *cptr)
 {
@@ -533,12 +438,22 @@ parse_config_outputOption(const char *token, char *cptr)
   }
 }
 
+void
+parse_config_addForwarderInfo(const char *token, char *cptr)
+{
+    if (netsnmp_ds_parse_boolean(cptr) == 1) {
+        netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID,
+                               NETSNMP_DS_LIB_ADD_FORWARDER_INFO, 1);
+    }
+}
+
 static void
 snmptrapd_main_loop(void)
 {
     int             count, numfds, block;
     fd_set          readfds,writefds,exceptfds;
-    struct timeval  timeout, *tvp;
+    struct timeval  timeout;
+    NETSNMP_SELECT_TIMEVAL timeout2;
 
     while (netsnmp_running) {
         if (reconfig) {
@@ -562,16 +477,16 @@ snmptrapd_main_loop(void)
         FD_ZERO(&writefds);
         FD_ZERO(&exceptfds);
         block = 0;
-        tvp = &timeout;
-        timerclear(tvp);
-        tvp->tv_sec = 5;
-        snmp_select_info(&numfds, &readfds, tvp, &block);
-        if (block == 1)
-            tvp = NULL;         /* block without timeout */
+        timerclear(&timeout);
+        timeout.tv_sec = 5;
+        snmp_select_info(&numfds, &readfds, &timeout, &block);
 #ifndef NETSNMP_FEATURE_REMOVE_FD_EVENT_MANAGER
         netsnmp_external_event_info(&numfds, &readfds, &writefds, &exceptfds);
 #endif /* NETSNMP_FEATURE_REMOVE_FD_EVENT_MANAGER */
-        count = select(numfds, &readfds, &writefds, &exceptfds, tvp);
+        timeout2.tv_sec = timeout.tv_sec;
+        timeout2.tv_usec = timeout.tv_usec;
+        count = select(numfds, &readfds, &writefds, &exceptfds,
+                       !block ? &timeout2 : NULL);
         if (count > 0) {
 #ifndef NETSNMP_FEATURE_REMOVE_FD_EVENT_MANAGER
             netsnmp_dispatch_external_events(&count, &readfds, &writefds,
@@ -633,7 +548,6 @@ main(int argc, char *argv[])
     netsnmp_session *sess_list = NULL, *ss = NULL;
     netsnmp_transport *transport = NULL;
     int             arg, i = 0;
-    int             uid = 0, gid = 0;
     int             exit_code = 1;
     char           *cp, *listen_ports = NULL;
 #if defined(USING_AGENTX_SUBAGENT_MODULE) && !defined(NETSNMP_SNMPTRAPD_DISABLE_AGENTX)
@@ -693,11 +607,11 @@ main(int argc, char *argv[])
 #endif
 #ifdef HAVE_UNISTD_H
     register_config_handler("snmptrapd", "agentuser",
-                            parse_config_agentuser, NULL, "userid");
+                            netsnmp_parse_agent_user, NULL, "userid");
     register_config_handler("snmptrapd", "agentgroup",
-                            parse_config_agentgroup, NULL, "groupid");
+                            netsnmp_parse_agent_group, NULL, "groupid");
 #endif
-    
+
     register_config_handler("snmptrapd", "doNotFork",
                             parse_config_doNotFork, NULL, "(1|yes|true|0|no|false)");
 
@@ -707,6 +621,10 @@ main(int argc, char *argv[])
     register_config_handler("snmptrapd", "outputOption",
                             parse_config_outputOption, NULL, "string");
 
+    register_config_handler("snmptrapd", "addForwarderInfo",
+                            parse_config_addForwarderInfo, NULL,
+                            "(1|yes|true|0|no|false)");
+
 #ifndef NETSNMP_FEATURE_REMOVE_LOGGING_SYSLOG
 #ifdef WIN32
     snmp_log_syslogname(app_name_long);
@@ -794,8 +712,24 @@ main(int argc, char *argv[])
 #if HAVE_UNISTD_H
         case 'g':
             if (optarg != NULL) {
-                netsnmp_ds_set_int(NETSNMP_DS_APPLICATION_ID, 
-				   NETSNMP_DS_AGENT_GROUPID, gid = atoi(optarg));
+                int gid;
+                char *ecp;
+
+                gid = strtoul(optarg, &ecp, 10);
+#if defined(HAVE_GETGRNAM) && defined(HAVE_PWD_H)
+                if (*ecp) {
+                    struct group  *info;
+
+                    info = getgrnam(optarg);
+                    gid = info ? info->gr_gid : -1;
+                    endgrent();
+                }
+#endif
+                if (gid < 0) {
+                    fprintf(stderr, "Bad group id: %s\n", optarg);
+                    goto out;
+                }
+                netsnmp_set_agent_group_id(gid);
             } else {
                 usage();
                 goto out;
@@ -908,10 +842,11 @@ main(int argc, char *argv[])
 #if HAVE_UNISTD_H
         case 'u':
             if (optarg != NULL) {
+                int             uid;
                 char           *ecp;
 
                 uid = strtoul(optarg, &ecp, 10);
-#if HAVE_GETPWNAM && HAVE_PWD_H
+#if defined(HAVE_GETPWNAM) && defined(HAVE_PWD_H)
                 if (*ecp) {
                     struct passwd  *info;
 
@@ -924,8 +859,7 @@ main(int argc, char *argv[])
                     fprintf(stderr, "Bad user id: %s\n", optarg);
                     goto out;
                 }
-                netsnmp_ds_set_int(NETSNMP_DS_APPLICATION_ID, 
-				   NETSNMP_DS_AGENT_USERID, uid);
+                netsnmp_set_agent_user_id(uid);
             } else {
                 usage();
                 goto out;
@@ -1206,7 +1140,7 @@ main(int argc, char *argv[])
     if (dofork && netsnmp_running) {
         int             fd;
 
-#if HAVE_FORKALL
+#ifdef HAVE_FORKALL
         switch (forkall()) {
 #else
         switch (fork()) {
@@ -1262,6 +1196,9 @@ main(int argc, char *argv[])
 
 #if HAVE_UNISTD_H
 #ifdef HAVE_SETGID
+    {
+    int gid;
+
     if ((gid = netsnmp_ds_get_int(NETSNMP_DS_APPLICATION_ID, 
 				  NETSNMP_DS_AGENT_GROUPID)) > 0) {
         DEBUGMSGTL(("snmptrapd/main", "Changing gid to %d.\n", gid));
@@ -1277,8 +1214,12 @@ main(int argc, char *argv[])
             }
         }
     }
+    }
 #endif
 #ifdef HAVE_SETUID
+    {
+    int uid;
+
     if ((uid = netsnmp_ds_get_int(NETSNMP_DS_APPLICATION_ID, 
 				  NETSNMP_DS_AGENT_USERID)) > 0) {
         DEBUGMSGTL(("snmptrapd/main", "Changing uid to %d.\n", uid));
@@ -1290,6 +1231,7 @@ main(int argc, char *argv[])
             }
         }
     }
+    }
 #endif
 #endif
 
@@ -1370,9 +1312,8 @@ trapd_update_config(void)
 * Invokes appropriate startup functions depending on the 
 * parameters passed
 *************************************************************/
-int
-    __cdecl
-_tmain(int argc, TCHAR * argv[])
+int __cdecl
+main(int argc, TCHAR * argv[])
 {
     /*
      * Define Service Name and Description, which appears in windows SCM 
@@ -1387,7 +1328,7 @@ _tmain(int argc, TCHAR * argv[])
 #endif
     InputParams     InputOptions;
 
-    int             nRunType = RUN_AS_CONSOLE;
+    enum net_snmp_cmd_line_action nRunType = RUN_AS_CONSOLE;
     int             quiet = 0;
 
     nRunType = ParseCmdLineForServiceOption(argc, argv, &quiet);
