@@ -3,7 +3,7 @@
 #ifndef SNMPIPV4BASE_H
 #define SNMPIPV4BASE_H
 
-#if HAVE_NETINET_IN_H
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
 
