@@ -7,7 +7,7 @@
 #     modify it under the same terms as Perl itself.
 
 package SNMP;
-$VERSION = '5.07021';   # current release version number
+$VERSION = '5.0903';   # current release version number
 
 use strict;
 use warnings;
@@ -223,10 +223,10 @@ sub translateObj {
 # Translate object identifier(tag or numeric) into alternate representation
 # (i.e., sysDescr => '.1.3.6.1.2.1.1.1' and '.1.3.6.1.2.1.1.1' => sysDescr)
 # when $SNMP::use_long_names or second arg is non-zero the translation will
-# return longer textual identifiers (e.g., system.sysDescr).  An optional 
+# return longer textual identifiers (e.g., system.sysDescr).  An optional
 # third argument of non-zero will cause the module name to be prepended
-# to the text name (e.g. 'SNMPv2-MIB::sysDescr').  If no Mib is loaded 
-# when called and $SNMP::auto_init_mib is enabled then the Mib will be 
+# to the text name (e.g. 'SNMPv2-MIB::sysDescr').  If no Mib is loaded
+# when called and $SNMP::auto_init_mib is enabled then the Mib will be
 # loaded. Will return 'undef' upon failure.
    SNMP::init_snmp("perl");
    my $obj = shift;
@@ -350,17 +350,17 @@ sub snmp_trap {
     $sess->trap(@_);
 }
 
-#--------------------------------------------------------------------- 
-# Preserves the ability to call MainLoop() with no args so we don't 
+#---------------------------------------------------------------------
+# Preserves the ability to call MainLoop() with no args so we don't
 # break old code
 #
-# Alternately, MainLoop() could be called as an object method, 
-# ( $sess->MainLoop() ) , so that $self winds up in @_.  Then it would 
+# Alternately, MainLoop() could be called as an object method,
+# ( $sess->MainLoop() ) , so that $self winds up in @_.  Then it would
 # be more like :
 # my $self = shift;
-# .... 
+# ....
 # SNMP::_main_loop(......, $self->{SessPtr});
-#--------------------------------------------------------------------- 
+#---------------------------------------------------------------------
 sub MainLoop {
     my $ss = shift if(&SNMP::_api_mode() == SNMP::SNMP_API_SINGLE());
     my $time = shift;
@@ -427,16 +427,16 @@ sub _tie {
 }
 
 sub split_vars {
-    # This sub holds the regex that is used throughout this module  
+    # This sub holds the regex that is used throughout this module
     #  to parse the base part of an OID from the IID.
-    #  eg: portName.9.30 -> ['portName','9.30'] 
+    #  eg: portName.9.30 -> ['portName','9.30']
     my $vars = shift;
 
     # The regex was changed to this simple form by patch 722075 for some reason.
-    # Testing shows now (2/05) that it is not needed, and that the long expression 
+    # Testing shows now (2/05) that it is not needed, and that the long expression
     # works fine.  AB
     # my ($tag, $iid) = ($vars =~ /^(.*?)\.?(\d+)+$/);
-    
+
     # These following two are the same.  Broken down for easier maintenance
     # my ($tag, $iid) = ($vars =~ /^((?:\.\d+)+|(?:\w+(?:\-*\w+)+))\.?(.*)$/);
     my ($tag, $iid) =
@@ -471,8 +471,8 @@ sub new {
    $this->{ErrorStr} = ''; # if methods return undef check for expln.
    $this->{ErrorNum} = 0;  # contains SNMP error return
 
-   $this->{Version} ||= 
-     NetSNMP::default_store::netsnmp_ds_get_int(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID, 
+   $this->{Version} ||=
+     NetSNMP::default_store::netsnmp_ds_get_int(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID,
 				      NetSNMP::default_store::NETSNMP_DS_LIB_SNMPVERSION) ||
 					SNMP::SNMP_DEFAULT_VERSION();
 
@@ -488,7 +488,7 @@ sub new {
    $this->{DestHost} ||= 'localhost';
 
    # community defaults to public
-   $this->{Community} ||= NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
+   $this->{Community} ||= NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
 				        NetSNMP::default_store::NETSNMP_DS_LIB_COMMUNITY()) || 'public';
 
    # number of retries before giving up, defaults to SNMP_DEFAULT_RETRIES
@@ -519,22 +519,22 @@ sub new {
 					     $this->{Timeout},
 					     );
    } elsif ($this->{Version} eq '3' ) {
-       $this->{SecName} ||= 
-	   NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
-		         NetSNMP::default_store::NETSNMP_DS_LIB_SECNAME()) || 
+       $this->{SecName} ||=
+	   NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
+		         NetSNMP::default_store::NETSNMP_DS_LIB_SECNAME()) ||
 			   'initial';
        if (!$this->{SecLevel}) {
-	   $this->{SecLevel} = 
-	       NetSNMP::default_store::netsnmp_ds_get_int(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
-			  NetSNMP::default_store::NETSNMP_DS_LIB_SECLEVEL()) || 
+	   $this->{SecLevel} =
+	       NetSNMP::default_store::netsnmp_ds_get_int(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
+			  NetSNMP::default_store::NETSNMP_DS_LIB_SECLEVEL()) ||
 			      $SNMP::V3_SEC_LEVEL_MAP{'noAuthNoPriv'};
        } elsif ($this->{SecLevel} !~ /^\d+$/) {
 	   $this->{SecLevel} = $SNMP::V3_SEC_LEVEL_MAP{$this->{SecLevel}};
        }
        $this->{SecEngineId} ||= '';
        $this->{ContextEngineId} ||= $this->{SecEngineId};
-       $this->{Context} ||= 
-	   NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
+       $this->{Context} ||=
+	   NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
 		         NetSNMP::default_store::NETSNMP_DS_LIB_CONTEXT()) || '';
 
        if ($this->{DestHost} =~ /^(dtls|tls|ssh)/) {
@@ -569,9 +569,9 @@ sub new {
 	   # USM specific parameters:
 	   $this->{AuthProto} ||= 'DEFAULT'; # use the library's default
 	   $this->{AuthPass} ||=
-	     NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
+	     NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
 							   NetSNMP::default_store::NETSNMP_DS_LIB_AUTHPASSPHRASE()) ||
-							       NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
+							       NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
 													     NetSNMP::default_store::NETSNMP_DS_LIB_PASSPHRASE()) || '';
 
 	   $this->{AuthMasterKey} ||= '';
@@ -581,9 +581,9 @@ sub new {
 
 	   $this->{PrivProto} ||= 'DEFAULT'; # use the library's default
 	   $this->{PrivPass} ||=
-	     NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
+	     NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
 							   NetSNMP::default_store::NETSNMP_DS_LIB_PRIVPASSPHRASE()) ||
-							       NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
+							       NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(),
 													     NetSNMP::default_store::NETSNMP_DS_LIB_PASSPHRASE()) || '';
 	   $this->{EngineBoots} = 0 if not defined $this->{EngineBoots};
 	   $this->{EngineTime} = 0 if not defined $this->{EngineTime};
@@ -622,9 +622,9 @@ sub new {
 
    SNMP::initMib($SNMP::auto_init_mib); # ensures that *some* mib is loaded
 
-   $this->{UseLongNames} = $SNMP::use_long_names 
+   $this->{UseLongNames} = $SNMP::use_long_names
        unless exists $this->{UseLongNames};
-   $this->{UseSprintValue} = $SNMP::use_sprint_value 
+   $this->{UseSprintValue} = $SNMP::use_sprint_value
        unless exists $this->{UseSprintValue};
    $this->{BestGuess} = $SNMP::best_guess unless exists $this->{BestGuess};
    $this->{NonIncreasing} ||= $SNMP::non_increasing;
@@ -651,9 +651,9 @@ sub update {
 
    @$this{keys %new_fields} = values %new_fields;
 
-   $this->{UseLongNames} = $SNMP::use_long_names 
+   $this->{UseLongNames} = $SNMP::use_long_names
        unless exists $this->{UseLongNames};
-   $this->{UseSprintValue} = $SNMP::use_sprint_value 
+   $this->{UseSprintValue} = $SNMP::use_sprint_value
        unless exists $this->{UseSprintValue};
    $this->{BestGuess} = $SNMP::best_guess unless exists $this->{BestGuess};
    $this->{NonIncreasing} ||= $SNMP::non_increasing;
@@ -754,7 +754,7 @@ sub gettable {
     return if (!$root_oid);
 
     # deficed if we're going to parse indexes
-    my $parse_indexes = (defined($state->{'options'}{'noindexes'})) ? 
+    my $parse_indexes = (defined($state->{'options'}{'noindexes'})) ?
       0 : $have_netsnmp_oid;
 
     # get the list of columns we should look at.
@@ -811,7 +811,7 @@ sub gettable {
     }
 
     $vbl = $state->{'varbinds'};
-	
+
     my $repeatcount;
     if ($this->{Version} eq '1' || $state->{'options'}{nogetbulk}) {
 	$state->{'repeatcount'} = 1;
@@ -890,7 +890,7 @@ sub _gettable_do_it() {
 	    my $row_value = $vbl->[$i][2];
 	    my $row_type = $vbl->[$i][3];
 
-	    if ($row_oid =~ 
+	    if ($row_oid =~
 		/^$state->{'stopconds'}[$i % ($#{$state->{'stopconds'}}+1)]/ &&
 		$row_value ne 'ENDOFMIBVIEW' ){
 
@@ -1185,7 +1185,7 @@ sub trap {
      $varbind_list_ref = $vars if ref($$vars[0]) =~ /ARRAY/;
    }
 
-   if ($this->{Version} eq '1') {
+   if ($this->{Version} =~ '^1') {
        my $enterprise = $param{enterprise} || 'ucdavis';
        $enterprise = SNMP::translateObj($enterprise)
 	   unless $enterprise =~ /^[\.\d]+$/;
@@ -1196,10 +1196,12 @@ sub trap {
        my $specific = $param{specific} || 0;
        @res = SNMP::_trapV1($this, $enterprise, $agent, $generic, $specific,
 			  $uptime, $varbind_list_ref);
-   } elsif  (($this->{Version} eq '2')|| ($this->{Version} eq '2c')) {
+   } elsif ($this->{Version} =~ '^[23]') {
        my $trap_oid = $param{oid} || $param{trapoid} || '.0.0';
        my $uptime = $param{uptime} || SNMP::_sys_uptime();
        @res = SNMP::_trapV2($this, $uptime, $trap_oid, $varbind_list_ref);
+   } else {
+     warn("error:trap: Unsupported SNMP version " . $this->{Version} . "\n");
    }
 
    return(wantarray() ? @res : $res[0]);
@@ -1234,7 +1236,7 @@ sub inform {
    my $trap_oid = $param{oid} || $param{trapoid};
    my $uptime = $param{uptime} || SNMP::_sys_uptime();
 
-   if($this->{Version} eq '3') {
+   if ($this->{Version} =~ '^[23]') {
      @res = SNMP::_inform($this, $uptime, $trap_oid, $varbind_list_ref, $cb);
    } else {
      warn("error:inform: This version doesn't support the command\n");
@@ -1621,7 +1623,7 @@ filename that holds the certificate.
 
 =item TheirIdentity
 
-The remote server's identity to connect to, specified as eihter a
+The remote server's identity to connect to, specified as either a
 fingerprint or a file name.  Either this must be specified, or the
 hostname below along with a trust anchor.
 
@@ -1634,10 +1636,10 @@ avoid man-in-the-middle attacks).
 
 =item TrustCert
 
-A trusted certificate to use a trust anchor (like a CA certificate)
+A trusted certificate to use as trust anchor (like a CA certificate)
 for verifying a remote server's certificate.  If a CA certificate is
 used to validate a certificate then the TheirHostname parameter must
-also be specified to ensure their presente hostname in the certificate
+also be specified to ensure their presented hostname in the certificate
 matches.
 
 =back
@@ -1661,7 +1663,9 @@ The default is 'noAuthNoPriv'.
 =item SecEngineId
 
 The SNMPv3 security engineID to use (if the snmpv3 security model
-needs it; for example USM).
+needs it; for example USM). The format is as a string without the leading '0x'.
+So if snmptrapd.conf has C<-e 0x8000000001020304>, use C<< SecEngineId =>
+'8000000001020304' >>.
 
 The default is <none>, security engineID and it will be probed if not
 supplied (v3)
@@ -1719,12 +1723,16 @@ the keys instead of deriving them from a password as above).
 
 =head2 SNMPv1 and SNMPv2c Options
 
+=over
+
 =item Community
 
 For SNMPv1 and SNMPv2c, the clear-text community name to use.
 
 The default is 'public'.
 
+=back
+
 =head2 Other Configuration Options
 
 =over
@@ -1784,8 +1792,8 @@ set so that the full OID is returned to the caller.
 
 defaults to the value of SNMP::best_guess at time of session
 creation. this setting controls how <tags> are parsed.  setting to
-0 causes a regular lookup.  setting to 1 causes a regular expression 
-match (defined as -Ib in snmpcmd) and setting to 2 causes a random 
+0 causes a regular lookup.  setting to 1 causes a regular expression
+match (defined as -Ib in snmpcmd) and setting to 2 causes a random
 access lookup (defined as -IR in snmpcmd).
 
 =item NonIncreasing
@@ -1935,7 +1943,7 @@ agent to include one additional (unrelated) variable that signals
 the end of the sub-tree, allowing bulkwalk() to determine that
 the request is complete.
 
-=item $results = $sess->gettable(E<lt>TABLE OIDE<gt>, E<lt>OPTIONS<gt>)
+=item $results = $sess->gettable(E<lt>TABLE OIDE<gt>, E<lt>OPTIONSE<gt>)
 
 This will retrieve an entire table of data and return a hash reference
 to that data.  The returned hash reference will have indexes of the
@@ -2017,7 +2025,7 @@ If a callback is specified, gettable will return quickly without
 returning results.  When the results are finally retrieved the
 callback subroutine will be called (see the other sections defining
 callback behaviour and how to make use of SNMP::MainLoop which is
-required fro this to work).  An additional argument of the normal hash
+required for this to work).  An additional argument of the normal hash
 result will be added to the callback subroutine arguments.
 
 Note 1: internally, the gettable function uses it's own callbacks
@@ -2247,7 +2255,7 @@ will be undef.
 
 to be used with async SNMP::Session
 calls. MainLoop must be called after initial async calls
-so return packets from the agent will not be processed.
+so return packets from the agent will be processed.
 If no args supplied this function enters an infinite loop
 so program must be exited in a callback or externally
 interrupted. If <timeout(sic)
@@ -2317,11 +2325,11 @@ returned.  Set on a per-session basis (see UseNumeric).
 
 =item $SNMP::best_guess
 
-default '0'.  This setting controls how <tags> are 
-parsed.  Setting to 0 causes a regular lookup.  Setting 
-to 1 causes a regular expression match (defined as -Ib 
-in snmpcmd) and setting to 2 causes a random access 
-lookup (defined as -IR in snmpcmd).  Can also be set 
+default '0'.  This setting controls how <tags> are
+parsed.  Setting to 0 causes a regular lookup.  Setting
+to 1 causes a regular expression match (defined as -Ib
+in snmpcmd) and setting to 2 causes a random access
+lookup (defined as -IR in snmpcmd).  Can also be set
 on a per session basis (see BestGuess)
 
 =item $SNMP::save_descriptions
@@ -2522,16 +2530,16 @@ B<*Not Implemented*>
 will convert a text obj tag to an OID and vice-versa.
 Any iid suffix is retained numerically.  Default
 behaviour when converting a numeric OID to text
-form is to return leaf identifier only 
-(e.g.,'sysDescr') but when $SNMP::use_long_names 
-is non-zero or a non-zero second arg is supplied it 
-will return a longer textual identifier.  An optional 
-third argument of non-zero will cause the module name 
-to be prepended to the text name (e.g. 
-'SNMPv2-MIB::sysDescr').  When converting a text obj, 
-the $SNMP::best_guess option is used.  If no Mib is 
-loaded when called and $SNMP::auto_init_mib is enabled 
-then the Mib will be loaded. Will return 'undef' upon 
+form is to return leaf identifier only
+(e.g.,'sysDescr') but when $SNMP::use_long_names
+is non-zero or a non-zero second arg is supplied it
+will return a longer textual identifier.  An optional
+third argument of non-zero will cause the module name
+to be prepended to the text name (e.g.
+'SNMPv2-MIB::sysDescr').  When converting a text obj,
+the $SNMP::best_guess option is used.  If no Mib is
+loaded when called and $SNMP::auto_init_mib is enabled
+then the Mib will be loaded. Will return 'undef' upon
 failure.
 
 =item &SNMP::getType(<var>)
