@@ -49,6 +49,9 @@ SOFTWARE.
 
 #include <stdio.h>
 #include <errno.h>
+#ifdef HAVE_INTTYPES_H
+#include <inttypes.h>
+#endif
 #if HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
@@ -74,23 +77,19 @@ SOFTWARE.
 #if HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
-#if HAVE_NETINET_IN_H
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
-#if HAVE_ARPA_INET_H
+#ifdef HAVE_ARPA_INET_H
 #include <arpa/inet.h>
 #endif
-#if HAVE_SYS_SELECT_H
+#ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
-#if HAVE_SYSLOG_H
+#ifdef HAVE_SYSLOG_H
 #include <syslog.h>
 #endif
 
-#if HAVE_DMALLOC_H
-#include <dmalloc.h>
-#endif
-
 #include <net-snmp/types.h>
 
 #include <net-snmp/agent/ds_agent.h>
@@ -105,12 +104,12 @@ SOFTWARE.
 #include <net-snmp/library/large_fd_set.h>
 #include <net-snmp/pdu_api.h>
 
-netsnmp_feature_child_of(snmp_client_all, libnetsnmp)
+netsnmp_feature_child_of(snmp_client_all, libnetsnmp);
 
-netsnmp_feature_child_of(snmp_split_pdu, snmp_client_all)
-netsnmp_feature_child_of(snmp_reset_var_types, snmp_client_all)
-netsnmp_feature_child_of(query_set_default_session, snmp_client_all)
-netsnmp_feature_child_of(row_create, snmp_client_all)
+netsnmp_feature_child_of(snmp_split_pdu, snmp_client_all);
+netsnmp_feature_child_of(snmp_reset_var_types, snmp_client_all);
+netsnmp_feature_child_of(query_set_default_session, snmp_client_all);
+netsnmp_feature_child_of(row_create, snmp_client_all);
 
 #ifndef BSD4_3
 #define BSD4_2
@@ -402,27 +401,16 @@ _clone_pdu_header(netsnmp_pdu *pdu)
         return NULL;
     }
 
-    if (pdu->securityStateRef &&
-        pdu->command == SNMP_MSG_TRAP2) {
-
-        ret = usm_clone_usmStateReference((struct usmStateReference *) pdu->securityStateRef,
-                (struct usmStateReference **) &newpdu->securityStateRef );
-
-        if (ret)
-        {
+    sptr = find_sec_mod(newpdu->securityModel);
+    if (sptr && sptr->pdu_clone) {
+        /* call security model if it needs to know about this */
+        ret = sptr->pdu_clone(pdu, newpdu);
+        if (ret) {
             snmp_free_pdu(newpdu);
             return NULL;
         }
     }
 
-    if ((sptr = find_sec_mod(newpdu->securityModel)) != NULL &&
-        sptr->pdu_clone != NULL) {
-        /*
-         * call security model if it needs to know about this 
-         */
-        (*sptr->pdu_clone) (pdu, newpdu);
-    }
-
     return newpdu;
 }
 
@@ -503,7 +491,7 @@ _copy_pdu_vars(netsnmp_pdu *pdu,        /* source PDU */
                int copy_count)
 {                               /* !=0 number of variables to copy */
     netsnmp_variable_list *var;
-#if TEMPORARILY_DISABLED
+#ifdef TEMPORARILY_DISABLED
     int             copied;
 #endif
     int             drop_idx;
@@ -520,24 +508,24 @@ _copy_pdu_vars(netsnmp_pdu *pdu,        /* source PDU */
     while (var && (skip_count-- > 0))   /* skip over pdu variables */
         var = var->next_variable;
 
-#if TEMPORARILY_DISABLED
+#ifdef TEMPORARILY_DISABLED
     copied = 0;
     if (pdu->flags & UCD_MSG_FLAG_FORCE_PDU_COPY)
         copied = 1;             /* We're interested in 'empty' responses too */
 #endif
 
     newpdu->variables = _copy_varlist(var, drop_idx, copy_count);
-#if TEMPORARILY_DISABLED
+#ifdef TEMPORARILY_DISABLED
     if (newpdu->variables)
         copied = 1;
 #endif
 
-#if ALSO_TEMPORARILY_DISABLED
+#ifdef ALSO_TEMPORARILY_DISABLED
     /*
      * Error if bad errindex or if target PDU has no variables copied 
      */
     if ((drop_err && (ii < pdu->errindex))
-#if TEMPORARILY_DISABLED
+#ifdef TEMPORARILY_DISABLED
         /*
          * SNMPv3 engineID probes are allowed to be empty.
          * See the comment in snmp_api.c for further details 
@@ -566,7 +554,10 @@ netsnmp_pdu    *
 _clone_pdu(netsnmp_pdu *pdu, int drop_err)
 {
     netsnmp_pdu    *newpdu;
+
     newpdu = _clone_pdu_header(pdu);
+    if (!newpdu)
+        return newpdu;
     newpdu = _copy_pdu_vars(pdu, newpdu, drop_err, 0, 10000);   /* skip none, copy all */
 
     return newpdu;
@@ -612,7 +603,10 @@ netsnmp_pdu    *
 snmp_split_pdu(netsnmp_pdu *pdu, int skip_count, int copy_count)
 {
     netsnmp_pdu    *newpdu;
+
     newpdu = _clone_pdu_header(pdu);
+    if (!newpdu)
+        return newpdu;
     newpdu = _copy_pdu_vars(pdu, newpdu, 0,     /* don't drop any variables */
                             skip_count, copy_count);
 
@@ -757,7 +751,7 @@ count_varbinds(netsnmp_variable_list * var_ptr)
     return count;
 }
 
-netsnmp_feature_child_of(count_varbinds_of_type, netsnmp_unused)
+netsnmp_feature_child_of(count_varbinds_of_type, netsnmp_unused);
 #ifndef NETSNMP_FEATURE_REMOVE_COUNT_VARBINDS_OF_TYPE
 int
 count_varbinds_of_type(netsnmp_variable_list * var_ptr, u_char type)
@@ -772,7 +766,7 @@ count_varbinds_of_type(netsnmp_variable_list * var_ptr, u_char type)
 }
 #endif /* NETSNMP_FEATURE_REMOVE_COUNT_VARBINDS_OF_TYPE */
 
-netsnmp_feature_child_of(find_varind_of_type, netsnmp_unused)
+netsnmp_feature_child_of(find_varind_of_type, netsnmp_unused);
 #ifndef NETSNMP_FEATURE_REMOVE_FIND_VARIND_OF_TYPE
 netsnmp_variable_list *
 find_varbind_of_type(netsnmp_variable_list * var_ptr, u_char type)
@@ -859,7 +853,8 @@ snmp_set_var_value(netsnmp_variable_list * vars,
                 = (const u_long *) value;
             *(vars->val.integer) = *val_ulong;
             if (*(vars->val.integer) > 0xffffffff) {
-                snmp_log(LOG_ERR,"truncating integer value > 32 bits\n");
+                NETSNMP_LOGONCE((LOG_INFO,
+                                 "truncating integer value > 32 bits\n"));
                 *(vars->val.integer) &= 0xffffffff;
             }
         }
@@ -871,7 +866,8 @@ snmp_set_var_value(netsnmp_variable_list * vars,
                 = (const unsigned long long *) value;
             *(vars->val.integer) = (long) *val_ullong;
             if (*(vars->val.integer) > 0xffffffff) {
-                snmp_log(LOG_ERR,"truncating integer value > 32 bits\n");
+                NETSNMP_LOGONCE((LOG_INFO,
+                                 "truncating integer value > 32 bits\n"));
                 *(vars->val.integer) &= 0xffffffff;
             }
         }
@@ -883,7 +879,8 @@ snmp_set_var_value(netsnmp_variable_list * vars,
                 = (const uintmax_t *) value;
             *(vars->val.integer) = (long) *val_uintmax_t;
             if (*(vars->val.integer) > 0xffffffff) {
-                snmp_log(LOG_ERR,"truncating integer value > 32 bits\n");
+                NETSNMP_LOGONCE((LOG_INFO,
+                                 "truncating integer value > 32 bits\n"));
                 *(vars->val.integer) &= 0xffffffff;
             }
         }
@@ -903,8 +900,8 @@ snmp_set_var_value(netsnmp_variable_list * vars,
 #endif
         else if (vars->val_len == sizeof(char)) {
             if (ASN_INTEGER == vars->type) {
-                const char      *val_char 
-                    = (const char *) value;
+                const signed char   *val_char
+                    = (const signed char *) value;
                 *(vars->val.integer) = (long) *val_char;
             } else {
                     const u_char    *val_uchar
@@ -973,7 +970,7 @@ snmp_set_var_value(netsnmp_variable_list * vars,
     case ASN_OPAQUE_I64:
 #endif                          /* NETSNMP_WITH_OPAQUE_SPECIAL_TYPES */
     case ASN_COUNTER64:
-        if (largeval) {
+        if (largeval || vars->val_len != sizeof(struct counter64)) {
             snmp_log(LOG_ERR,"bad size for counter 64 (%d)\n",
                      (int)vars->val_len);
             return (1);
